@@ -10,8 +10,7 @@ from python_toolbox import import_tools
 from python_toolbox.temp_value_setting import TempValueSetter
 
 import python_toolbox
-from python_toolbox.address_tools import (describe,
-                                                  resolve)
+from python_toolbox.address_tools import describe, resolve
 
 # todo: Make test that when a root or namespace is given, it's top priority to
 # use it, even if it prevents shorterning and results in an overall longer
@@ -28,9 +27,9 @@ def test_on_locally_defined_class():
     # Testing for locally defined class:
     
     
-    if python_toolbox.__version_info__ <= (0, 6, 2, 'release'):
+    if python_toolbox.__version_info__ <= (0, 6, 3, 'release'):
         raise nose.SkipTest("This test doesn't pass in `python_toolbox` "
-                            "version 0.6.2 and below, because `describe` :"
+                            "version 0.6.3 and below, because `describe` :"
                             "doesn't support nested classes yet.")
     
     result = describe(A.B)
@@ -248,9 +247,9 @@ def test_bad_module_name():
 
 def test_function_in_something():
     '''Test `describe` doesn't fail when describing `{1: sum}`.'''
-    if python_toolbox.__version_info__ <= (0, 6, 2, 'release'):
+    if python_toolbox.__version_info__ <= (0, 6, 3, 'release'):
         raise nose.SkipTest("This test doesn't pass in `python_toolbox`"
-                            "version 0.6.2 and below.")
+                            "version 0.6.3 and below.")
     assert describe({1: sum}) == '{1: sum}'
     assert describe((sum, sum, list, chr)) == '(sum, sum, list, chr)'
     
