@@ -161,10 +161,10 @@ class ArgumentsProfile:
         # `dict` that maps from argument name to default value:
         defaults = OrderedDict(zip(defaultful_args, s_defaults))
         
-        defaultful_args_differing_from_defaults = set((
+        defaultful_args_differing_from_defaults = {
             defaultful_arg for defaultful_arg in defaultful_args
             if defaults[defaultful_arg] != getcallargs_result[defaultful_arg]
-        ))
+        }
         
         if s_star_args and getcallargs_result[s_star_args]:
             # We have some arguments that go into `*args`! This means that we
@@ -179,19 +179,19 @@ class ArgumentsProfile:
 
             # `dict` mapping from each defaultful arg to the "price" of
             # specifying its value:
-            prices_of_values = OrderedDict((
-                (defaultful_arg, len(repr(getcallargs_result[defaultful_arg])))
+            prices_of_values = OrderedDict({
+                defaultful_arg: len(repr(getcallargs_result[defaultful_arg]))
                  for defaultful_arg in defaultful_args
-            ))
+            })
             # The price is simply the string length of the value's `repr`.
             
             # `dict` mapping from each defaultful arg to the "price" of
             # specifying it as a keyword (not including the length of the
             # value):
-            prices_of_keyword_prefixes = OrderedDict(
-                ((defaultful_arg, len(defaultful_arg)+1) for 
-                 defaultful_arg in defaultful_args)
-            )
+            prices_of_keyword_prefixes = OrderedDict({
+                defaultful_arg: len(defaultful_arg)+1 for 
+                                              defaultful_arg in defaultful_args
+            })
             # For example, if we have a defaultful arg "gravity_strength", then
             # specifiying it by keyword will require using the string
             # "gravity_strength=", which is 17 characters long, therefore the
