@@ -16,10 +16,10 @@ from python_toolbox import pickle_tools
 my_messy_object = (
     'Whatever',
     {1: 2,}, 
-    set([3, 4]), 
+    {3, 4}, 
     frozenset([3, 4]),
     ((((((((((((())))))))))))),
-    'unicode_too',
+    u'unicode_too',
     (((((3, 4, 5j)))))
 )
 
